Skip to contents

Prints the model metadata and power table returned by rmst.power().

Returns a summary object for printing and further inspection.

Prints and returns the stored ggplot2 object.

Usage

# S3 method for class 'rmst_power'
print(x, ...)

# S3 method for class 'rmst_power'
summary(object, ...)

# S3 method for class 'rmst_power'
plot(x, ...)

Arguments

x

An object returned by rmst.power().

...

Additional arguments passed to or from other methods.

object

An object returned by rmst.power().

Value

The input object x, invisibly.

An object of class "summary.rmst_power".

A ggplot2 object, invisibly.