Prints the model metadata and sample-size table returned by rmst.ss().
Returns a summary object for printing and further inspection.
Prints and returns the stored ggplot2 object.
Prints the model metadata and sample-size table returned by rmst.ss().
Returns a summary object for printing and further inspection.
Prints and returns the stored ggplot2 object.