Prints the model metadata and power table returned by rmst.power().
Returns a summary object for printing and further inspection.
Prints and returns the stored ggplot2 object.
Arguments
- x
An object returned by
rmst.power().- ...
Additional arguments passed to or from other methods.
- object
An object returned by
rmst.power().